@@ -32,12 +32,18 @@ db.connect <- function (host = "localhost", user = Sys.getenv("USER"), dbname =
         i <- which(tolower(.supported.connections) == conn.pkg.name)
         pkg.to.load <- .supported.connections[i]
         ## if the package is not installed, install it
-        if (!(conn.pkg.name %in% .get.installed.pkgs())) 
+        installed.pkgs <- .get.installed.pkgs()
+        if (!(conn.pkg.name %in% installed.pkgs)) 
         {
+            if (conn.pkg.name == "rpostgresql" && !("dbi" %in% installed.pkgs)) {
+                message("Package DBI is going to be installed!\n")
+                install.packages(paste(.localVars$pkg.path, "/dbi/DBI.tar.gz",
+                                       sep = ""), repos = NULL, type = "source")
+            }
             message(paste("Package ", pkg.to.load,
-                        " is going to be installed so that ",
-                        .this.pkg.name,
-                        " could connect to databases.\n\n", sep = ""))
+                          " is going to be installed so that ",
+                          .this.pkg.name,
+                          " could connect to databases.\n", sep = ""))
             install.packages(pkgs = pkg.to.load)
             if (!(conn.pkg.name %in% .get.installed.pkgs()))
                 stop("The package could not be installed!")
@@ -63,6 +69,10 @@ db.connect <- function (host = "localhost", user = Sys.getenv("USER"), dbname =
                      "function db.default.schemas or db.search.path ",
                      "to display or set the current default schemas.")
         }
+
+        res <- .get.res(paste("set application_name = '",
+                              .this.pkg.name, "'", sep = ""),
+                        conn.id = result)
         
         return (result)
     }
@@ -104,7 +114,7 @@ db.search.path <- function (conn.id = 1, set = NULL)
 ## ---------------------------------------------------------------------- 
 
 ## disconnect a connection
-db.disconnect <- function (conn.id = 1, verbose = TRUE)
+db.disconnect <- function (conn.id = 1, verbose = TRUE, force = FALSE)
 {
     ## check whether this connection exists
     if (!.is.conn.id.valid(conn.id))
@@ -115,7 +125,7 @@ db.disconnect <- function (conn.id = 1, verbose = TRUE)
     command <- paste(".db.disconnect.", conn.pkg, "(idx=", idx, ")",
                      sep = "")
     res <- eval(parse(text = command))
-    if (res)
+    if (res || force)
     {
         .localVars$db[[idx]] <- NULL
         .localVars$conn.type[[conn.pkg]] <- .localVars$conn.type[[conn.pkg]][-which(.localVars$conn.type[[conn.pkg]]==conn.id)]
@@ -129,8 +139,12 @@ db.disconnect <- function (conn.id = 1, verbose = TRUE)
             .localVars$conn.id[.localVars$conn.id[,1] == id, 2] <- i
         }
 
-        if (verbose)
-            cat(paste("Connection", conn.id, "is disconnected!\n"))
+        if (verbose) {
+            if (force)
+                cat(paste("Connection", conn.id, "is forcely removed!\n"))
+            else
+                cat(paste("Connection", conn.id, "is disconnected!\n"))
+        }
     }
     else
     {
@@ -196,10 +210,10 @@ db.list <- function ()
             else
                 cat("MADlib   :    installed in schema", schema.madlib(idx[1]), "\n")
             
-            pkg <- .localVars$db[[idx[2]]]$conn.pkg
-            id <- which(tolower(.supported.connections) == pkg)
-            cat(paste("Conn pkg :    ", .supported.connections[id],
-                      "\n", sep = ""))
+            ## pkg <- .localVars$db[[idx[2]]]$conn.pkg
+            ## id <- which(tolower(.supported.connections) == pkg)
+            ## cat(paste("Conn pkg :    ", .supported.connections[id],
+            ##           "\n", sep = ""))
         }
         cat("\n")
     }
@@ -210,6 +224,9 @@ db.list <- function ()
 ## list tables and views in the connection
 db.objects <- function (search = NULL, conn.id = 1)
 {
+    if (!.is.conn.id.valid(conn.id))
+        stop("Connection ID ", conn.id, " is not valid!")
+        
     res <- .db.getQuery("select table_schema, table_name from information_schema.tables", conn.id = conn.id)
 
     if (is.null(search)) {
@@ -221,7 +238,7 @@ db.objects <- function (search = NULL, conn.id = 1)
     final.res <- character(0)
     for (i in seq_len(dim(res)[1])) {
         name <- paste(res[i,1], ".", res[i,2], sep = "")
-        find <- gsub(search, "", name)
+        find <- gsub(search, "", name, perl = TRUE)
         if (find != name)
             final.res <- rbind(final.res, res[i,])
     }
@@ -237,25 +254,48 @@ db.objects <- function (search = NULL, conn.id = 1)
 ## does an object exist?
 db.existsObject <- function (name, conn.id = 1, is.temp = FALSE)
 {
+    warns <- .suppress.warnings (conn.id)
     if (length(name) == 1) name <- strsplit(name, "\\.")[[1]]
     if (length(name) != 1 && length(name) != 2)
         stop("The formation of object name is wrong!")
     if (length(name) == 2) {
+        if (is.temp) stop("Temporary tables may not specify a schema name!")
         schema <- name[1]
         table <- name[2]
-        ct <- .db.getQuery(paste("select count(*) from information_schema.tables where table_name = '",
-                                 .strip(table, "\""),
-                                 "' and table_schema = '",
-                                 .strip(schema, "\""), "'", sep = ""), conn.id)
-        if (ct == 0)
+        ct <- .get.res(sql=paste("select count(*) from ",
+                       "information_schema.tables where ",
+                       "table_name = '",
+                       .strip(table, "\""),
+                       "' and table_schema = '",
+                       .strip(schema, "\""), "'", sep = ""),
+                       conn.id=conn.id, warns=warns)
+        if (ct == 0) {
+            .restore.warnings(warns)
             FALSE
-        else
+        } else {
+            .restore.warnings(warns)
             TRUE
+        }
     } else {
         if (is.temp)
             .db.existsTempTable(name, conn.id)
-        else
-            .db.existsTable(name, conn.id)
+        else {
+            schemas <- arraydb.to.arrayr(
+                .get.res(sql="select current_schemas(True)",
+                         conn.id=conn.id, warns=warns),
+                type = "character")
+            table_schema <- character(0)
+            for (schema in schemas)
+                if (.db.existsTable(c(schema, name), conn.id))
+                    table_schema <- c(table_schema, schema)
+            if (identical(table_schema, character(0))) {
+                .restore.warnings(warns)
+                FALSE
+            } else {
+                .restore.warnings(warns)
+                TRUE
+            }
+        }
     }
 }
 
