@@ -38,6 +38,7 @@
 
     is.factor <- data@.is.factor
     cols <- names(data)
+    
     params <- .analyze.formula(formula, data, params$data, refresh = TRUE,
                                is.factor = is.factor, cols = cols,
                                suffix = data@.factor.suffix)
@@ -50,20 +51,24 @@
 ## -----------------------------------------------------------------------
 
 ## get the result
-.get.res <- function (sql, tbl.output = NULL, conn.id)
+.get.res <- function (sql, tbl.output = NULL, conn.id, warns = NULL)
 {
     ## execute the linear regression
     res <- try(.db.getQuery(sql, conn.id), silent = TRUE)
-    if (is(res, .err.class))
+    if (is(res, .err.class)) {
+        if (!is.null(warns)) .restore.warnings(warns)
         stop("Could not run SQL query !")
+    }
 
     ## retreive result
     if (!is.null(tbl.output)) {
         res <- try(.db.getQuery(paste("select * from", tbl.output),
                                 conn.id),
                    silent = TRUE)
-        if (is(res, .err.class))
+        if (is(res, .err.class)) {
+            if (!is.null(warns)) .restore.warnings(warns)
             stop("Could not retreive result from SQL query !")
+        }
     }
 
     res
